#

##

##

##

##

##

##

##

##

    	UFW

    	GUFW
    		apt install gufw

    	Status
    		ufw status verbose numbered

    			ufw delete {} --force

    	block everything
    		ufw default deny outgoing
    		ufw default deny incoming

    	allow
    		everything
    			ufw default allow outgoing
    			ufw default allow incoming

    		address access
    			ufw allow out to ecosia.com port 443/tcp

    		port access
    			ufw allow out 80/tcp
    			ufw allow out 443/tcp

    	Delete All Rules

    		ufw reset --force